import React, { FC, ReactNode } from 'react';
import { Button as ButtonX, Icon, NativeBase, Text } from 'native-base';
import { StyleSheet } from 'react-native';

const primaryColor = '#FD8282';
export type ButtonTypeProps =
  | 'custom-full'
  | 'custom'
  | 'primary'
  | 'warning'
  | 'success'
  | 'transparent'
  | 'danger';
export type ButtonProps = NativeBase.Button & {
  type?: ButtonTypeProps;
  buttonProps?: any;
  iconName?: string;
  textProps?: NativeBase.Text;
  iconProps?: NativeBase.Icon;
  children: ReactNode;
};
const styles = StyleSheet.create({
  input: {
    borderWidth: 1,
    borderColor: '#999999',
    borderRadius: 6,
    paddingLeft: 10,
    marginBottom: 15,
  },
  default: {
    // borderWidth: 1,
    // borderColor: '#999999',
    borderRadius: 6,
    flexDirection: 'row',
    backgroundColor: 'white',
    justifyContent: 'center',
    alignItems: 'center',
  },
  primary: {
    // borderWidth: 1,
    // borderColor: '#999999',
    borderRadius: 6,
    flexDirection: 'row',
    backgroundColor: primaryColor,
    justifyContent: 'center',
    alignItems: 'center',
  },
  transparent: {
    borderWidth: 2,
    borderColor: primaryColor,
    borderRadius: 6,
    flexDirection: 'row',
    // backgroundColor: primaryColor,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textDefault: {
    color: primaryColor,
    justifyContent: 'center',
    fontFamily: 'roboto',
    fontWeight: 'normal',
    fontSize: 17,
  },
  iconDefault: {
    color: primaryColor,
    justifyContent: 'center',
    fontSize: 25,
  },
  textPrimary: {
    color: 'white',
    justifyContent: 'center',
    fontSize: 17,
  },
  iconPrimary: {
    color: 'white',
    justifyContent: 'center',
    fontSize: 25,
  },
});

export const Button: FC<ButtonProps> = (props: ButtonProps) => {
  const { textProps, iconProps, type, iconName, children } = props;
  const propsX = { ...props };
  delete propsX.textProps;
  delete propsX.iconProps;
  if (iconName) {
    propsX.icon = true;
  }
  const renderButton = (buttonStyle: any, textStyle: any, iconStyle: any) => {
    if (type === 'transparent') {
      propsX.transparent = true;
    }
    return (
      <ButtonX
        {...propsX}
        bordered={false}
        style={
          propsX.style
            ? { ...(propsX.style as object), ...buttonStyle }
            : buttonStyle
        }
      >
        <Text {...textProps} uppercase={false} style={textStyle}>
          {iconName && (
            <Icon {...iconProps} name={iconName} style={iconStyle} />
          )}
          &nbsp;
          {children}
        </Text>
      </ButtonX>
    );
  };
  switch (type) {
    case 'primary':
      return renderButton(
        styles.default,
        styles.textDefault,
        styles.iconDefault
      );
    case 'success':
      return renderButton(
        { ...styles.primary, backgroundColor: '#2ED47A' },
        styles.textPrimary,
        styles.iconPrimary
      );
    case 'danger':
      return renderButton(
        { ...styles.primary, backgroundColor: '#F50E0E' },
        styles.textPrimary,
        styles.iconPrimary
      );
    case 'warning':
      return renderButton(
        { ...styles.primary, backgroundColor: '#FFCF5C' },
        styles.textPrimary,
        styles.iconPrimary
      );
    case 'transparent':
      return renderButton(
        styles.transparent,
        styles.textPrimary,
        styles.iconPrimary
      );
    case 'custom-full':
      return <ButtonX {...propsX}>{props.children}</ButtonX>;
    case 'custom':
      return (
        <ButtonX {...propsX}>
          {propsX.icon && <Icon {...iconProps} />}
          <Text uppercase={false} {...textProps}>
            {props.children}
          </Text>
        </ButtonX>
      );
    default:
      return renderButton(
        styles.primary,
        styles.textPrimary,
        styles.iconPrimary
      );
  }
};
