import React, { FC } from 'react';
import {
  Input as InputX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { StyleSheet } from 'react-native';
const styles = StyleSheet.create({
  material: {
    borderColor: 'white',
    borderBottomWidth: 1,
    color: 'white',
  },
  textMaterial: {
    color: 'white',
    fontFamily: 'roboto',
    fontWeight: 'normal',
    fontSize: 17,
  },
  default: {
    borderBottomWidth: 0,
    borderRadius: 5,
    backgroundColor: 'white',
    margin: 0,
  },
  textDefault: {
    color: 'white',
    marginBottom: 13,
    fontFamily: 'roboto',
    fontWeight: 'normal',
    fontSize: 17,
  },
  itemStyle: {
    marginBottom: 10,
    borderBottomWidth: 0,
  },
});
type Props = NativeBase.Input & {
  type?: 'material' | 'primary';
  inputStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  inputProps?: NativeBase.Input;
  // children: ReactNode;
};
export const Input: FC<Props> = (props: Props) => {
  const { type, label, labelProps, style, inputStyle } = props;
  const propsX = { ...props };
  propsX.style = inputStyle;
  delete propsX.labelProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.inputStyle;

  const renderElement = (inputStyleX?: any, labelStyle?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}
        <InputX
          {...propsX}
          style={inputStyle ? { ...inputStyleX, ...inputStyle } : inputStyleX}
        />
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    // case 'custom':
    //   return (
    //     <ButtonX {...propsX}>
    //       {propsX.icon && <Icon {...iconProps} />}
    //       <Text uppercase={false} {...textProps}>{props.children}</Text>
    //     </ButtonX>
    //   );
    default:
      return renderElement(styles.default, styles.textDefault);
  }
};
